FreeDiscovery
=============

.. image:: https://travis-ci.org/FreeDiscovery/FreeDiscovery.svg?branch=master
    :target: https://travis-ci.org/FreeDiscovery/FreeDiscovery

.. image:: https://ci.appveyor.com/api/projects/status/w5kjscmqlrlehp5t/branch/master?svg=true
    :target: https://ci.appveyor.com/project/FreeDiscovery/freediscovery/branch/master


Open Source Software for E-Discovery and Information Retrieval

FreeDiscovery is built on top of existing machine learning libraries (scikit-learn) and provides REST web services for information retrieval applications. It aims to benefit existing e-discovery platforms with a focus on the following functionality, 

- text categorization
- document clustering
- duplicate detection
- semantic search
- e-mail threading

In addition, FreeDiscovery can be used as Python package and aims to expose a scikit-learn compatible API. 

We would very much appreciate feedback on the existing functionality. Feel free to open new issues on Github or send any comments to the mailing list https://groups.google.com/forum/#!forum/freediscovery-ml at `freediscovery-ml@googlegroups.com <mailto:freediscovery-ml@googlegroups.com>`_.

For more information see the documentation and API Reference,

 - development version [``master`` branch | documentation https://freediscovery.github.io/doc/dev/ ].
 - stable version 0.9 [``0.9.X`` branch | documentation https://freediscovery.github.io/doc/stable/ ].

FreeDiscovery is released under the 3-clause BSD licence.

.. image:: https://freediscovery.github.io/static/grossmanlabs-old-logo-small.gif
    :target: http://www.grossmanlabs.com/
